public interface HttpServerResponse extends HttpResponse, HttpStatusCodeAccessor.HttpStatusCodeProperty, HttpStatusCodeAccessor.HttpStatusCodeBuilder<HttpServerResponse>, HttpBodyAccessor.HttpBodyProvider<BadResponseException>, org.refcodes.mixin.Dumpable
HttpServerResponse as produced by the server.HeaderFieldsAccessor.HeaderFieldsBuilder<T extends HeaderFields<?,?>,B extends HeaderFieldsAccessor.HeaderFieldsBuilder<T,B>>, HeaderFieldsAccessor.HeaderFieldsMutator<T extends HeaderFields<?,?>>, HeaderFieldsAccessor.HeaderFieldsProperty<T extends HeaderFields<?,?>>HttpStatusCodeAccessor.HttpStatusCodeBuilder<B extends HttpStatusCodeAccessor.HttpStatusCodeBuilder<B>>, HttpStatusCodeAccessor.HttpStatusCodeMutator, HttpStatusCodeAccessor.HttpStatusCodeProperty| Modifier and Type | Method and Description |
|---|---|
<RES> RES |
getResponse()
Retrieves the response from the response property.
|
<RES> void |
setResponse(RES aResponse)
Sets the response for the response property.
|
default HttpServerResponse |
withHttpStatusCode(HttpStatusCode aStatusCode)
Sets the HTTP Status-Code for the HTTP Status-Code property.
|
default <RES> HttpServerResponse |
withResponse(RES aResponse)
Sets the response for the response property.
|
getHeaderFieldsgetHttpStatusCodesetHttpStatusCodetoHttpBodydefault HttpServerResponse withHttpStatusCode(HttpStatusCode aStatusCode)
withHttpStatusCode in interface HttpStatusCodeAccessor.HttpStatusCodeBuilder<HttpServerResponse>aStatusCode - The HTTP Status-Code to be stored by the HTTP HTTP
Status-Code property.<RES> RES getResponse()
RES - the generic type<RES> void setResponse(RES aResponse)
HttpServerResponseImpl.setResponse(Object) supports the
HttpBodyMap to marshal an HttpBodyMap into an HTTP
Request-Body.RES - the generic typeaResponse - The response to be stored by the response property.default <RES> HttpServerResponse withResponse(RES aResponse)
RES - the generic typeaResponse - The response to be stored by the response property.Copyright © 2018. All rights reserved.